Documentation
¶
Overview ¶
Package cookiejar implements an in-memory RFC 6265-compliant http.CookieJar.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
Types ¶
type Jar ¶
type Jar struct {
// contains filtered or unexported fields
}
Jar implements the http.CookieJar interface from the net/http package.
func (*Jar) Cookies ¶
Cookies implements the Cookies method of the http.CookieJar interface.
It returns an empty slice if the URL's scheme is not HTTP or HTTPS.
func (*Jar) DumpCookies ¶
DumpCookies dumps all cookies
type Options ¶
type Options struct {
// PublicSuffixList is the public suffix list that determines whether
// an HTTP server can set a cookie for a domain.
//
// A nil value is valid and may be useful for testing but it is not
// secure: it means that the HTTP server for foo.co.uk can set a cookie
// for bar.co.uk.
PublicSuffixList cookiejar.PublicSuffixList
}
Options are the options for creating a new Jar.
Click to show internal directories.
Click to hide internal directories.